@@ -7,14 +7,19 @@
 #' @return A data frame of available gene sets.
 #'
 #' @importFrom httr GET content
+#' @importFrom rjson fromJSON
 #' @export
 #'
 listGeneSet <- function(organism="hsapiens",hostName="http://www.webgestalt.org/"){
-	response <- GET(file.path(hostName, "api", "summary", "geneset"))
-	if (response$status_code != 200) {
-		return(webRequestError(response))
+	if (startsWith(hostName, "file://")) {
+		jsonData <- fromJSON(file=removeFileProtocol(file.path(hostName, "genesetsummary.json")))
+	} else {
+		response <- GET(file.path(hostName, "api", "summary", "geneset"))
+		if (response$status_code != 200) {
+			return(webRequestError(response))
+		}
+		jsonData <- content(response)
 	}
-	jsonData <- content(response)
 	ids <- jsonData[[organism]]
 	name1 <- names(ids)
 	idList <- data.frame(name="",description="",idType="",stringsAsFactors=F)
